@@ -71,15 +71,24 @@ namespace ts.formatting {
                 rules.push(this.globalRules.NoSpaceBetweenParens);
             }
 
-            if ( options.InsertSpaceAfterOpeningAndBeforeClosingNonemptyBrackets ) {
-                rules.push( this.globalRules.SpaceAfterOpenBracket );
-                rules.push( this.globalRules.SpaceBeforeCloseBracket );
-                rules.push( this.globalRules.NoSpaceBetweenBrackets );
+            if (options.InsertSpaceAfterOpeningAndBeforeClosingNonemptyBrackets) {
+                rules.push(this.globalRules.SpaceAfterOpenBracket);
+                rules.push(this.globalRules.SpaceBeforeCloseBracket);
+                rules.push(this.globalRules.NoSpaceBetweenBrackets);
             }
             else {
-                rules.push( this.globalRules.NoSpaceAfterOpenBracket );
-                rules.push( this.globalRules.NoSpaceBeforeCloseBracket );
-                rules.push( this.globalRules.NoSpaceBetweenBrackets );
+                rules.push(this.globalRules.NoSpaceAfterOpenBracket);
+                rules.push(this.globalRules.NoSpaceBeforeCloseBracket);
+                rules.push(this.globalRules.NoSpaceBetweenBrackets);
+            }
+
+            if (options.InsertSpaceAfterOpeningAndBeforeClosingTemplateStringBraces) {
+                rules.push(this.globalRules.SpaceAfterTemplateHeadAndMiddle);
+                rules.push(this.globalRules.SpaceBeforeTemplateMiddleAndTail);
+            }
+            else {
+                rules.push(this.globalRules.NoSpaceAfterTemplateHeadAndMiddle);
+                rules.push(this.globalRules.NoSpaceBeforeTemplateMiddleAndTail);
             }
 
             if (options.InsertSpaceAfterSemicolonInForStatements) {
