@@ -5,9 +5,10 @@ export class C {
 }
 
 //// [ExportAssignment8.js]
+"use strict";
 var C = (function () {
     function C() {
     }
     return C;
-})();
+}());
 exports.C = C;
