@@ -16,7 +16,9 @@ module M {
 }
 
 //// [aliasesInSystemModule2.js]
-System.register(["foo"], function(exports_1) {
+System.register(["foo"], function(exports_1, context_1) {
+    "use strict";
+    var __moduleName = context_1 && context_1.id;
     var foo_1;
     var cls, cls2, x, y, z, M;
     return {
