@@ -12,6 +12,7 @@ export = Foo;
 
 //// [amdModuleName2.js]
 define("SecondModuleName", ["require", "exports"], function (require, exports) {
+    "use strict";
     ///<amd-module name='FirstModuleName'/>
     ///<amd-module name='SecondModuleName'/>
     var Foo = (function () {
@@ -19,6 +20,6 @@ define("SecondModuleName", ["require", "exports"], function (require, exports) {
             this.x = 5;
         }
         return Foo;
-    })();
+    }());
     return Foo;
 });
