@@ -33,7 +33,7 @@ var Base = (function () {
     function Base() {
     }
     return Base;
-})();
+}());
 // is String (S) a subtype of U extends String (T)? Would only be true if we used the apparent type of U (T)
 var Derived = (function (_super) {
     __extends(Derived, _super);
@@ -41,12 +41,12 @@ var Derived = (function (_super) {
         _super.apply(this, arguments);
     }
     return Derived;
-})(Base);
+}(Base));
 var Base2 = (function () {
     function Base2() {
     }
     return Base2;
-})();
+}());
 // is U extends String (S) a subtype of String (T)? Apparent type of U is String so it succeeds
 var Derived2 = (function (_super) {
     __extends(Derived2, _super);
@@ -54,4 +54,4 @@ var Derived2 = (function (_super) {
         _super.apply(this, arguments);
     }
     return Derived2;
-})(Base2);
+}(Base2));
