@@ -71,7 +71,7 @@ var C1 = (function () {
     C1.prototype.IM1 = function () { return null; };
     C1.prototype.C1M1 = function () { return null; };
     return C1;
-})();
+}());
 var C2 = (function (_super) {
     __extends(C2, _super);
     function C2() {
@@ -79,13 +79,13 @@ var C2 = (function (_super) {
     }
     C2.prototype.C2M1 = function () { return null; };
     return C2;
-})(C1);
+}(C1));
 var C3 = (function () {
     function C3() {
     }
     C3.prototype.CM3M1 = function () { return 3; };
     return C3;
-})();
+}());
 /*
 
 This behaves unexpectedly with the following types:
