@@ -54,7 +54,7 @@ var C = (function () {
     function C() {
     }
     return C;
-})();
+}());
 var classArr = [new C(), new C()];
 var classTypeArray = [C, C, C];
 var classTypeArray; // Should OK, not be a parse error
@@ -66,14 +66,14 @@ var Base = (function () {
     function Base() {
     }
     return Base;
-})();
+}());
 var Derived1 = (function (_super) {
     __extends(Derived1, _super);
     function Derived1() {
         _super.apply(this, arguments);
     }
     return Derived1;
-})(Base);
+}(Base));
 ;
 var Derived2 = (function (_super) {
     __extends(Derived2, _super);
@@ -81,7 +81,7 @@ var Derived2 = (function (_super) {
         _super.apply(this, arguments);
     }
     return Derived2;
-})(Base);
+}(Base));
 ;
 var context3 = [new Derived1(), new Derived2()];
 // Contextual type C with numeric index signature of type Base makes array literal of Derived1 and Derived2 have type Base[]
