@@ -11,10 +11,10 @@ var c3 = (function () {
     }
     c3.prototype.foo = function () { };
     return c3;
-})(); // error
+}()); // error
 var c3 = (function () {
     function c3() {
     }
     c3.prototype.bar = function () { };
     return c3;
-})(); // error
+}()); // error
