@@ -117,7 +117,7 @@ var m1d;
         }
         I.prototype.foo = function () { };
         return I;
-    })();
+    }());
     m1d.I = I;
 })(m1d || (m1d = {}));
 var m1d = 1; // error
@@ -153,14 +153,14 @@ var m2g;
         }
         C.prototype.foo = function () { };
         return C;
-    })();
+    }());
     m2g.C = C;
 })(m2g || (m2g = {}));
 var m3 = (function () {
     function m3() {
     }
     return m3;
-})(); // ok since the module is not instantiated
+}()); // ok since the module is not instantiated
 var m3a;
 (function (m3a) {
     var y = 2;
@@ -170,13 +170,13 @@ var m3a = (function () {
     }
     m3a.prototype.foo = function () { };
     return m3a;
-})(); // error, class isn't ambient or declared before the module
+}()); // error, class isn't ambient or declared before the module
 var m3b = (function () {
     function m3b() {
     }
     m3b.prototype.foo = function () { };
     return m3b;
-})();
+}());
 var m3b;
 (function (m3b) {
     var y = 2;
@@ -186,7 +186,7 @@ var m3c = (function () {
     }
     m3c.prototype.foo = function () { };
     return m3c;
-})();
+}());
 var m3c;
 (function (m3c) {
     m3c.y = 2;
@@ -206,7 +206,7 @@ var m3g;
         }
         C.prototype.foo = function () { };
         return C;
-    })();
+    }());
     m3g.C = C;
 })(m3g || (m3g = {}));
 var m4;
@@ -239,7 +239,7 @@ var m4d;
         }
         C.prototype.foo = function () { };
         return C;
-    })();
+    }());
 })(m4d || (m4d = {}));
 var m4d;
 (function (m4d) {
