@@ -39,14 +39,14 @@ var C = (function () {
     function C(x, y) {
     }
     return C;
-})();
+}());
 var ELoc = (function (_super) {
     __extends(ELoc, _super);
     function ELoc(x) {
         _super.call(this, 0, x);
     }
     return ELoc;
-})(C);
+}(C));
 var ELocVar = (function (_super) {
     __extends(ELocVar, _super);
     function ELocVar(x) {
@@ -56,7 +56,7 @@ var ELocVar = (function (_super) {
         var loc = 10;
     };
     return ELocVar;
-})(C);
+}(C));
 var D = (function (_super) {
     __extends(D, _super);
     function D(z) {
@@ -64,7 +64,7 @@ var D = (function (_super) {
         this.z = z;
     }
     return D;
-})(C); // too few params
+}(C)); // too few params
 var E = (function (_super) {
     __extends(E, _super);
     function E(z) {
@@ -72,7 +72,7 @@ var E = (function (_super) {
         this.z = z;
     }
     return E;
-})(C);
+}(C));
 var F = (function (_super) {
     __extends(F, _super);
     function F(z) {
@@ -80,7 +80,7 @@ var F = (function (_super) {
         this.z = z;
     }
     return F;
-})(C); // first param type
+}(C)); // first param type
 function f() {
     if (x < 10) {
         x = 11;
