@@ -34,6 +34,7 @@ export module M1 {
 
 
 //// [foo1.js]
+"use strict";
 var foo2 = require('./foo2');
 var M1;
 (function (M1) {
@@ -44,10 +45,11 @@ var M1;
             this.m1.x = 20; // Error
         }
         return C1;
-    })();
+    }());
     M1.C1 = C1;
 })(M1 = exports.M1 || (exports.M1 = {}));
 //// [foo2.js]
+"use strict";
 var foo1 = require('./foo1');
 var M1;
 (function (M1) {
@@ -61,6 +63,6 @@ var M1;
             tmp.x = 20; // Error			
         }
         return C1;
-    })();
+    }());
     M1.C1 = C1;
 })(M1 = exports.M1 || (exports.M1 = {}));
