@@ -5,24 +5,25 @@ default abstract class C {}
 import abstract class D {}
 
 //// [classAbstractManyKeywords.js]
+"use strict";
 var A = (function () {
     function A() {
     }
     return A;
-})();
+}());
 var B = (function () {
     function B() {
     }
     return B;
-})();
+}());
 exports.B = B;
 var C = (function () {
     function C() {
     }
     return C;
-})();
+}());
 var D = (function () {
     function D() {
     }
     return D;
-})();
+}());
