@@ -12,11 +12,11 @@ var D = (function () {
     function D() {
     }
     return D;
-})();
+}());
 var v = (function (_super) {
     __extends(C, _super);
     function C() {
         _super.apply(this, arguments);
     }
     return C;
-})(D);
+}(D));
