@@ -43,14 +43,14 @@ var C = (function () {
     C.prototype.thing = function () { };
     C.other = function () { };
     return C;
-})();
+}());
 var D = (function (_super) {
     __extends(D, _super);
     function D() {
         _super.apply(this, arguments);
     }
     return D;
-})(C);
+}(C));
 var d;
 var r = d.foo;
 var r2 = d.bar;
@@ -62,14 +62,14 @@ var C2 = (function () {
     C2.prototype.thing = function (x) { };
     C2.other = function (x) { };
     return C2;
-})();
+}());
 var D2 = (function (_super) {
     __extends(D2, _super);
     function D2() {
         _super.apply(this, arguments);
     }
     return D2;
-})(C2);
+}(C2));
 var d2;
 var r5 = d2.foo;
 var r6 = d2.bar;
