@@ -15,11 +15,11 @@ var C1 = (function (_super) {
         _super.apply(this, arguments);
     }
     return C1;
-})(null);
+}(null));
 var C2 = (function (_super) {
     __extends(C2, _super);
     function C2() {
         _super.apply(this, arguments);
     }
     return C2;
-})((null));
+}((null)));
