@@ -17,18 +17,18 @@ var C = (function (_super) {
         _super.apply(this, arguments);
     }
     return C;
-})(C); // error
+}(C)); // error
 var D = (function (_super) {
     __extends(D, _super);
     function D() {
         _super.apply(this, arguments);
     }
     return D;
-})(D); // error
+}(D)); // error
 var E = (function (_super) {
     __extends(E, _super);
     function E() {
         _super.apply(this, arguments);
     }
     return E;
-})(E); // error
+}(E)); // error
