@@ -26,16 +26,16 @@ var bar = (function () {
         this.baz = new foo();
     }
     return bar;
-})();
+}());
 var baz = (function () {
     function baz() {
     }
     return baz;
-})();
+}());
 var foo = (function (_super) {
     __extends(foo, _super);
     function foo() {
         _super.apply(this, arguments);
     }
     return foo;
-})(baz);
+}(baz));
