@@ -50,14 +50,14 @@ var Base = (function () {
     function Base(x) {
     }
     return Base;
-})();
+}());
 var C = (function (_super) {
     __extends(C, _super);
     function C() {
         _super.apply(this, arguments);
     }
     return C;
-})(Base);
+}(Base));
 var r = C;
 var c = new C(); // error
 var c2 = new C(1); // ok
@@ -65,14 +65,14 @@ var Base2 = (function () {
     function Base2(x) {
     }
     return Base2;
-})();
+}());
 var D = (function (_super) {
     __extends(D, _super);
     function D() {
         _super.apply(this, arguments);
     }
     return D;
-})(Base2);
+}(Base2));
 var r2 = D;
 var d = new D(); // error
 var d2 = new D(1); // ok
@@ -83,7 +83,7 @@ var D2 = (function (_super) {
         _super.apply(this, arguments);
     }
     return D2;
-})(Base2);
+}(Base2));
 var r3 = D2;
 var d3 = new D(); // error
 var d4 = new D(1); // ok
@@ -93,7 +93,7 @@ var D3 = (function (_super) {
         _super.apply(this, arguments);
     }
     return D3;
-})(Base2);
+}(Base2));
 var r4 = D3;
 var d5 = new D(); // error
 var d6 = new D(1); // ok
