@@ -61,14 +61,14 @@ var NonGeneric;
         function C(x) {
         }
         return C;
-    })();
+    }());
     var c = new C(); // error
     var c2 = new C(''); // ok
     var C2 = (function () {
         function C2(x) {
         }
         return C2;
-    })();
+    }());
     var c3 = new C2(); // error
     var c4 = new C2(''); // ok
     var c5 = new C2(1); // ok
@@ -78,7 +78,7 @@ var NonGeneric;
             _super.apply(this, arguments);
         }
         return D;
-    })(C2);
+    }(C2));
     var d = new D(); // error
     var d2 = new D(1); // ok
     var d3 = new D(''); // ok
@@ -89,14 +89,14 @@ var Generics;
         function C(x) {
         }
         return C;
-    })();
+    }());
     var c = new C(); // error
     var c2 = new C(''); // ok
     var C2 = (function () {
         function C2(x) {
         }
         return C2;
-    })();
+    }());
     var c3 = new C2(); // error
     var c4 = new C2(''); // ok
     var c5 = new C2(1, 2); // ok
@@ -106,7 +106,7 @@ var Generics;
             _super.apply(this, arguments);
         }
         return D;
-    })(C2);
+    }(C2));
     var d = new D(); // error
     var d2 = new D(1); // ok
     var d3 = new D(''); // ok
