@@ -32,7 +32,7 @@ var Foo = (function () {
         var _super = 10; // No error
     };
     return Foo;
-})();
+}());
 var b = (function (_super) {
     __extends(b, _super);
     function b() {
@@ -42,7 +42,7 @@ var b = (function (_super) {
         var _super = 10; // Should be error 
     };
     return b;
-})(Foo);
+}(Foo));
 var c = (function (_super) {
     __extends(c, _super);
     function c() {
@@ -54,4 +54,4 @@ var c = (function (_super) {
         };
     };
     return c;
-})(Foo);
+}(Foo));
