@@ -40,14 +40,14 @@ var a = (function () {
     function a() {
     }
     return a;
-})();
+}());
 var b1 = (function (_super) {
     __extends(b1, _super);
     function b1(_super) {
         _super.call(this);
     }
     return b1;
-})(a);
+}(a));
 var b2 = (function (_super) {
     __extends(b2, _super);
     function b2(_super) {
@@ -55,14 +55,14 @@ var b2 = (function (_super) {
         this._super = _super;
     }
     return b2;
-})(a);
+}(a));
 var b3 = (function (_super) {
     __extends(b3, _super);
     function b3(_super) {
         _super.call(this);
     }
     return b3;
-})(a);
+}(a));
 var b4 = (function (_super) {
     __extends(b4, _super);
     function b4(_super) {
@@ -70,4 +70,4 @@ var b4 = (function (_super) {
         this._super = _super;
     }
     return b4;
-})(a);
+}(a));
