@@ -63,6 +63,7 @@ var newVar2 = new extMod.m4.m2.c();
 
 //// [commentsExternalModules_0.js]
 define(["require", "exports"], function (require, exports) {
+    "use strict";
     /** Module comment*/
     var m1;
     (function (m1) {
@@ -78,7 +79,7 @@ define(["require", "exports"], function (require, exports) {
                 function c() {
                 }
                 return c;
-            })();
+            }());
             m2.c = c;
             ;
             /** i*/
@@ -109,7 +110,7 @@ define(["require", "exports"], function (require, exports) {
                 function c() {
                 }
                 return c;
-            })();
+            }());
             m2.c = c;
             ;
             /** i */
@@ -126,6 +127,7 @@ define(["require", "exports"], function (require, exports) {
 });
 //// [commentsExternalModules_1.js]
 define(["require", "exports", "commentsExternalModules_0"], function (require, exports, extMod) {
+    "use strict";
     extMod.m1.fooExport();
     var newVar = new extMod.m1.m2.c();
     extMod.m4.fooExport();
