@@ -172,7 +172,7 @@ var c1 = (function () {
     c1.prototype.nc_f1 = function () {
     };
     return c1;
-})();
+}());
 var i1_i;
 var c1_i = new c1();
 // assign to interface
@@ -223,7 +223,7 @@ var c2 = (function () {
         configurable: true
     });
     return c2;
-})();
+}());
 var c3 = (function (_super) {
     __extends(c3, _super);
     function c3() {
@@ -250,7 +250,7 @@ var c3 = (function (_super) {
         configurable: true
     });
     return c3;
-})(c2);
+}(c2));
 var c2_i = new c2(10);
 var c3_i = new c3();
 // assign
@@ -261,7 +261,7 @@ var c4 = (function (_super) {
         _super.apply(this, arguments);
     }
     return c4;
-})(c2);
+}(c2));
 var c4_i = new c4(10);
 var i2_i;
 var i3_i;
