@@ -14,15 +14,17 @@ if(foo.C1.s1){
 
 
 //// [foo_0.js]
+"use strict";
 var C1 = (function () {
     function C1() {
         this.m1 = 42;
     }
     C1.s1 = true;
     return C1;
-})();
+}());
 exports.C1 = C1;
 //// [foo_1.js]
+"use strict";
 var foo = require("./foo_0");
 if (foo.C1.s1) {
 }
