@@ -207,7 +207,7 @@ var A1 = (function () {
         return null;
     };
     return A1;
-})();
+}());
 var B1 = (function () {
     function B1() {
     }
@@ -215,7 +215,7 @@ var B1 = (function () {
         return null;
     };
     return B1;
-})();
+}());
 var Base = (function () {
     function Base() {
     }
@@ -223,21 +223,21 @@ var Base = (function () {
         return null;
     };
     return Base;
-})();
+}());
 var A2 = (function (_super) {
     __extends(A2, _super);
     function A2() {
         _super.apply(this, arguments);
     }
     return A2;
-})(Base);
+}(Base));
 var B2 = (function (_super) {
     __extends(B2, _super);
     function B2() {
         _super.apply(this, arguments);
     }
     return B2;
-})(Base);
+}(Base));
 var a1;
 var a2;
 var a3;
