@@ -121,19 +121,19 @@ var Base = (function () {
     function Base() {
     }
     return Base;
-})();
+}());
 var Derived = (function (_super) {
     __extends(Derived, _super);
     function Derived() {
         _super.apply(this, arguments);
     }
     return Derived;
-})(Base);
+}(Base));
 var C = (function () {
     function C() {
     }
     return C;
-})();
+}());
 var a1;
 var b1;
 var a2;
