@@ -21,7 +21,7 @@ var Base = (function () {
         return 0;
     };
     return Base;
-})();
+}());
 var C = (function (_super) {
     __extends(C, _super);
     function C() {
@@ -29,4 +29,4 @@ var C = (function (_super) {
     }
     C.prototype[_super.bar.call(this)] = function () { };
     return C;
-})(Base);
+}(Base));
