@@ -20,7 +20,7 @@ var Base = (function () {
     function Base() {
     }
     return Base;
-})();
+}());
 var C = (function (_super) {
     __extends(C, _super);
     function C() {
@@ -32,4 +32,4 @@ var C = (function (_super) {
         var _a;
     }
     return C;
-})(Base);
+}(Base));
