@@ -28,7 +28,7 @@ var Base = (function () {
         return 0;
     };
     return Base;
-})();
+}());
 var C = (function (_super) {
     __extends(C, _super);
     function C() {
@@ -46,4 +46,4 @@ var C = (function (_super) {
         return 0;
     };
     return C;
-})(Base);
+}(Base));
