@@ -15,25 +15,21 @@ var Foo = (function () {
     function Foo() {
     }
     return Foo;
-})();
+}());
 var Foo2 = (function () {
     function Foo2() {
     }
     return Foo2;
-})();
+}());
 var C = (function () {
     function C() {
     }
     Object.defineProperty(C.prototype, "get1", {
         // Computed properties
         get: function () { return new Foo; },
-        enumerable: true,
-        configurable: true
-    });
-    Object.defineProperty(C.prototype, "set1", {
         set: function (p) { },
         enumerable: true,
         configurable: true
     });
     return C;
-})();
+}());
