@@ -22,12 +22,12 @@ var Foo = (function () {
     function Foo() {
     }
     return Foo;
-})();
+}());
 var Foo2 = (function () {
     function Foo2() {
     }
     return Foo2;
-})();
+}());
 var C = (function () {
     function C() {
     }
@@ -37,7 +37,7 @@ var C = (function () {
         configurable: true
     });
     return C;
-})();
+}());
 var D = (function (_super) {
     __extends(D, _super);
     function D() {
@@ -49,4 +49,4 @@ var D = (function (_super) {
         configurable: true
     });
     return D;
-})(C);
+}(C));
