@@ -1,4 +1,5 @@
 //// [conditionalExpressions2.ts]
+
 var a = false ? 1 : null;
 var b = false ? undefined : 0;
 var c = false ? 1 : 0;
@@ -18,11 +19,9 @@ var e = false ? "foo" : "bar";
 var f = false ? null : undefined;
 var g = true ? { g: 5 } : null;
 var h = [{ h: 5 }, null];
-function i() {
-    if (true) {
-        return { x: 5 };
-    }
-    else {
-        return null;
-    }
+function i() { if (true) {
+    return { x: 5 };
 }
+else {
+    return null;
+} }
