@@ -34,7 +34,7 @@ var X = (function () {
     function X() {
     }
     return X;
-})();
+}());
 ;
 var A = (function (_super) {
     __extends(A, _super);
@@ -42,7 +42,7 @@ var A = (function (_super) {
         _super.apply(this, arguments);
     }
     return A;
-})(X);
+}(X));
 ;
 var B = (function (_super) {
     __extends(B, _super);
@@ -50,7 +50,7 @@ var B = (function (_super) {
         _super.apply(this, arguments);
     }
     return B;
-})(X);
+}(X));
 ;
 var x;
 var a;
