@@ -1,4 +1,4 @@
-//// [constEnumMergingWithValues4.ts]
+//// [m1.ts]
 
 module foo {
     const enum E { X }
@@ -11,8 +11,9 @@ module foo {
 
 export = foo
 
-//// [constEnumMergingWithValues4.js]
+//// [m1.js]
 define(["require", "exports"], function (require, exports) {
+    "use strict";
     var foo;
     (function (foo) {
         var x = 1;
