@@ -1,4 +1,4 @@
-//// [constEnumMergingWithValues5.ts]
+//// [m1.ts]
 
 module foo {
     const enum E { X }
@@ -6,8 +6,9 @@ module foo {
 
 export = foo
 
-//// [constEnumMergingWithValues5.js]
+//// [m1.js]
 define(["require", "exports"], function (require, exports) {
+    "use strict";
     var foo;
     (function (foo) {
         var E;
