@@ -25,7 +25,7 @@ var Base = (function () {
     }
     Base.prototype.foo = function () { };
     return Base;
-})();
+}());
 var Derived1 = (function (_super) {
     __extends(Derived1, _super);
     function Derived1() {
@@ -33,7 +33,7 @@ var Derived1 = (function (_super) {
     }
     Derived1.prototype.bar = function () { };
     return Derived1;
-})(Base);
+}(Base));
 var Derived2 = (function (_super) {
     __extends(Derived2, _super);
     function Derived2() {
@@ -41,7 +41,7 @@ var Derived2 = (function (_super) {
     }
     Derived2.prototype.baz = function () { };
     return Derived2;
-})(Base);
+}(Base));
 var Derived3 = (function (_super) {
     __extends(Derived3, _super);
     function Derived3() {
@@ -49,7 +49,7 @@ var Derived3 = (function (_super) {
     }
     Derived3.prototype.biz = function () { };
     return Derived3;
-})(Base);
+}(Base));
 function foo(tagName) {
     return null;
 }
