@@ -125,26 +125,26 @@ var Errors;
         function Base() {
         }
         return Base;
-    })();
+    }());
     var Derived = (function (_super) {
         __extends(Derived, _super);
         function Derived() {
             _super.apply(this, arguments);
         }
         return Derived;
-    })(Base);
+    }(Base));
     var Derived2 = (function (_super) {
         __extends(Derived2, _super);
         function Derived2() {
             _super.apply(this, arguments);
         }
         return Derived2;
-    })(Derived);
+    }(Derived));
     var OtherDerived = (function (_super) {
         __extends(OtherDerived, _super);
         function OtherDerived() {
             _super.apply(this, arguments);
         }
         return OtherDerived;
-    })(Base);
+    }(Base));
 })(Errors || (Errors = {}));
