@@ -34,7 +34,7 @@ var Foo = (function (_super) {
     }
     Foo.prototype.bar1 = function () { };
     return Foo;
-})(FooBase);
+}(FooBase));
 var f1 = new Foo("hey");
 var f2 = new Foo(0);
 var f3 = new Foo(f1);
