@@ -21,14 +21,14 @@ var C = (function () {
         this.x = 1;
     }
     return C;
-})();
+}());
 var D = (function (_super) {
     __extends(D, _super);
     function D() {
         _super.apply(this, arguments);
     }
     return D;
-})(C);
+}(C));
 function foo(x, items) {
     return null;
 }
