@@ -10,6 +10,7 @@ export class BuildWorkspaceService {
 
 //// [crashIntypeCheckObjectCreationExpression.js]
 define(["require", "exports"], function (require, exports) {
+    "use strict";
     var BuildWorkspaceService = (function () {
         function BuildWorkspaceService() {
         }
@@ -19,6 +20,6 @@ define(["require", "exports"], function (require, exports) {
         BuildWorkspaceService.prototype.injectBuildService = function (service) {
         };
         return BuildWorkspaceService;
-    })();
+    }());
     exports.BuildWorkspaceService = BuildWorkspaceService;
 });
