@@ -23,6 +23,7 @@ export var x: c.b.m2.c1;
 
 //// [declFileExportImportChain2_a.js]
 define(["require", "exports"], function (require, exports) {
+    "use strict";
     var m1;
     (function (m1) {
         var m2;
@@ -31,7 +32,7 @@ define(["require", "exports"], function (require, exports) {
                 function c1() {
                 }
                 return c1;
-            })();
+            }());
             m2.c1 = c1;
         })(m2 = m1.m2 || (m1.m2 = {}));
     })(m1 || (m1 = {}));
@@ -39,14 +40,17 @@ define(["require", "exports"], function (require, exports) {
 });
 //// [declFileExportImportChain2_b.js]
 define(["require", "exports", "declFileExportImportChain2_a"], function (require, exports, a) {
+    "use strict";
     return a;
 });
 //// [declFileExportImportChain2_c.js]
 define(["require", "exports", "declFileExportImportChain2_b"], function (require, exports, b) {
+    "use strict";
     exports.b = b;
 });
 //// [declFileExportImportChain2_d.js]
 define(["require", "exports"], function (require, exports) {
+    "use strict";
 });
 
 
