@@ -22,19 +22,19 @@ var Base = (function () {
     function Base() {
     }
     return Base;
-})();
+}());
 var Derived = (function (_super) {
     __extends(Derived, _super);
     function Derived() {
         _super.apply(this, arguments);
     }
     return Derived;
-})(Base);
+}(Base));
 var Baz = (function () {
     function Baz() {
     }
     return Baz;
-})();
+}());
 
 
 //// [declFileGenericClassWithGenericExtendedClass.d.ts]
