@@ -10,6 +10,7 @@ import b = a;
 export = b;
 
 //// [declFileImportChainInExportAssignment.js]
+"use strict";
 var m;
 (function (m) {
     var c;
@@ -18,7 +19,7 @@ var m;
             function c() {
             }
             return c;
-        })();
+        }());
         c_1.c = c;
     })(c = m.c || (m.c = {}));
 })(m || (m = {}));
