@@ -32,7 +32,7 @@ var A;
             function EventManager() {
             }
             return EventManager;
-        })();
+        }());
         B.EventManager = EventManager;
     })(B = A.B || (A.B = {}));
 })(A || (A = {}));
@@ -48,7 +48,7 @@ var A;
                     _super.apply(this, arguments);
                 }
                 return ContextMenu;
-            })(B.EventManager);
+            }(B.EventManager));
             C.ContextMenu = ContextMenu;
         })(C = B.C || (B.C = {}));
     })(B = A.B || (A.B = {}));
