@@ -11,6 +11,7 @@ module m {
 export = m;
 
 //// [declarationEmitImportInExportAssignmentModule.js]
+"use strict";
 var m;
 (function (m) {
     var c;
@@ -19,7 +20,7 @@ var m;
             function c() {
             }
             return c;
-        })();
+        }());
         c_1.c = c;
     })(c = m.c || (m.c = {}));
 })(m || (m = {}));
