@@ -24,11 +24,11 @@ var D = (function (_super) {
         _super.apply(this, arguments);
     }
     return D;
-})(ab.C);
+}(ab.C));
 var E = (function (_super) {
     __extends(E, _super);
     function E() {
         _super.apply(this, arguments);
     }
     return E;
-})(A.B.C);
+}(A.B.C));
