@@ -22,9 +22,11 @@ class Wat {
 }
 
 //// [a.js]
+"use strict";
 // from #3108
 exports.test = 'abc';
 //// [b.js]
+"use strict";
 var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
     var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
     if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
@@ -47,4 +49,4 @@ var Wat = (function () {
         filter(function () { return a_1.test == 'abc'; })
     ], Wat, "whatever", null);
     return Wat;
-})();
+}());
