@@ -18,12 +18,13 @@ export class B {
 
 
 //// [decoratorMetadataWithConstructorType.js]
+"use strict";
 var A = (function () {
     function A() {
         console.log('new A');
     }
     return A;
-})();
+}());
 function decorator(target, propertyKey) {
 }
 var B = (function () {
@@ -35,5 +36,5 @@ var B = (function () {
         __metadata('design:type', A)
     ], B.prototype, "x", void 0);
     return B;
-})();
+}());
 exports.B = B;
