@@ -6,6 +6,7 @@ export class C {
 }
 
 //// [decoratorOnClass2.js]
+"use strict";
 var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
     var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
     if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
@@ -19,5 +20,5 @@ var C = (function () {
         dec
     ], C);
     return C;
-})();
+}());
 exports.C = C;
