@@ -43,36 +43,36 @@ var Base = (function () {
     function Base() {
     }
     return Base;
-})();
+}());
 var Derived = (function (_super) {
     __extends(Derived, _super);
     function Derived() {
     }
     return Derived;
-})(Base);
+}(Base));
 var Base2 = (function () {
     function Base2() {
     }
     return Base2;
-})();
+}());
 var Derived2 = (function (_super) {
     __extends(Derived2, _super);
     function Derived2() {
         var r2 = function () { return _super.call(this); }; // error for misplaced super call (nested function)
     }
     return Derived2;
-})(Base2);
+}(Base2));
 var Derived3 = (function (_super) {
     __extends(Derived3, _super);
     function Derived3() {
         var r = function () { _super.call(this); }; // error
     }
     return Derived3;
-})(Base2);
+}(Base2));
 var Derived4 = (function (_super) {
     __extends(Derived4, _super);
     function Derived4() {
         var r = _super.call(this); // ok
     }
     return Derived4;
-})(Base2);
+}(Base2));
