@@ -27,7 +27,7 @@ var Base = (function () {
     function Base() {
     }
     return Base;
-})();
+}());
 // ok, use assignment compatibility
 var Derived = (function (_super) {
     __extends(Derived, _super);
@@ -35,12 +35,12 @@ var Derived = (function (_super) {
         _super.apply(this, arguments);
     }
     return Derived;
-})(Base);
+}(Base));
 var Base2 = (function () {
     function Base2() {
     }
     return Base2;
-})();
+}());
 // ok, use assignment compatibility
 var Derived2 = (function (_super) {
     __extends(Derived2, _super);
@@ -48,4 +48,4 @@ var Derived2 = (function (_super) {
         _super.apply(this, arguments);
     }
     return Derived2;
-})(Base2);
+}(Base2));
