@@ -38,14 +38,14 @@ var Base = (function () {
     function Base(a) {
     }
     return Base;
-})();
+}());
 var Derived = (function (_super) {
     __extends(Derived, _super);
     function Derived() {
         _super.call(this, this); // ok
     }
     return Derived;
-})(Base);
+}(Base));
 var Derived2 = (function (_super) {
     __extends(Derived2, _super);
     function Derived2(a) {
@@ -53,7 +53,7 @@ var Derived2 = (function (_super) {
         this.a = a;
     }
     return Derived2;
-})(Base);
+}(Base));
 var Derived3 = (function (_super) {
     __extends(Derived3, _super);
     function Derived3(a) {
@@ -62,7 +62,7 @@ var Derived3 = (function (_super) {
         this.a = a;
     }
     return Derived3;
-})(Base);
+}(Base));
 var Derived4 = (function (_super) {
     __extends(Derived4, _super);
     function Derived4(a) {
@@ -70,4 +70,4 @@ var Derived4 = (function (_super) {
         this.a = a;
     }
     return Derived4;
-})(Base);
+}(Base));
