@@ -41,7 +41,7 @@ var Base = (function () {
         configurable: true
     });
     return Base;
-})();
+}());
 // error, not a subtype
 var Derived = (function (_super) {
     __extends(Derived, _super);
@@ -58,4 +58,4 @@ var Derived = (function (_super) {
         configurable: true
     });
     return Derived;
-})(Base);
+}(Base));
