@@ -1,4 +1,5 @@
 //// [doWhileBreakStatements.ts]
+
 do {
     break;
 } while(true)
@@ -66,7 +67,6 @@ SEVEN: do
     while (true);
 while (true);
 EIGHT: do {
-    var fn = function () {
-    };
+    var fn = function () { };
     break EIGHT;
 } while (true);
