@@ -1,4 +1,5 @@
 //// [downlevelLetConst18.ts]
+
 'use strict'
 
 for (let x; ;) {
@@ -6,7 +7,7 @@ for (let x; ;) {
 }
 
 for (let x; ;) {
-    function foo() { x };
+    function foo1() { x };
 }
 
 for (let x; ;) {
@@ -32,26 +33,47 @@ for (let x; ;) {
 
 //// [downlevelLetConst18.js]
 'use strict';
-for (var x = void 0;;) {
+var _loop_1 = function(x) {
     function foo() { x; }
     ;
-}
+};
 for (var x = void 0;;) {
-    function foo() { x; }
+    _loop_1(x);
+}
+var _loop_2 = function(x) {
+    function foo1() { x; }
     ;
-}
+};
 for (var x = void 0;;) {
+    _loop_2(x);
+}
+var _loop_3 = function(x) {
     (function () { x; })();
+};
+for (var x = void 0;;) {
+    _loop_3(x);
 }
+var _loop_4 = function(x) {
+    (function () { x; })();
+};
 for (var x = 1;;) {
-    (function () { x; })();
+    _loop_4(x);
 }
-for (var x = void 0;;) {
+var _loop_5 = function(x) {
     ({ foo: function () { x; } });
-}
+};
 for (var x = void 0;;) {
+    _loop_5(x);
+}
+var _loop_6 = function(x) {
     ({ get foo() { return x; } });
-}
+};
 for (var x = void 0;;) {
+    _loop_6(x);
+}
+var _loop_7 = function(x) {
     ({ set foo(v) { x; } });
+};
+for (var x = void 0;;) {
+    _loop_7(x);
 }
