@@ -67,6 +67,7 @@ export interface D { }
 
 //// [duplicateSymbolsExportMatching.js]
 define(["require", "exports"], function (require, exports) {
+    "use strict";
     // Should report error only once for instantiated module
     var M;
     (function (M) {
@@ -100,7 +101,7 @@ define(["require", "exports"], function (require, exports) {
             function C() {
             }
             return C;
-        })();
+        }());
         var C;
         (function (C) {
             var t;
