@@ -4,6 +4,7 @@ class B extends A {
 }
 
 //// [emptyModuleName.js]
+"use strict";
 var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
@@ -16,4 +17,4 @@ var B = (function (_super) {
         _super.apply(this, arguments);
     }
     return B;
-})(A);
+}(A));
