@@ -26,11 +26,11 @@ var base = (function () {
         this.n = n;
     }
     return base;
-})();
+}());
 var derived = (function (_super) {
     __extends(derived, _super);
     function derived() {
         _super.apply(this, arguments);
     }
     return derived;
-})(base);
+}(base));
