@@ -23,6 +23,7 @@ export class A
         define(["require", "exports"], factory);
     }
 })(function (require, exports) {
+    "use strict";
     var A = (function () {
         function A() {
         }
@@ -30,6 +31,6 @@ export class A
             return 42;
         };
         return A;
-    })();
+    }());
     exports.A = A;
 });
