@@ -25,6 +25,7 @@ export = A;
         define(["require", "exports"], factory);
     }
 })(function (require, exports) {
+    "use strict";
     var A = (function () {
         function A() {
         }
@@ -32,6 +33,6 @@ export = A;
             return 42;
         };
         return A;
-    })();
+    }());
     return A;
 });
