@@ -14,6 +14,7 @@ module A {
 export = A
 
 //// [es5ExportEqualsDts.js]
+"use strict";
 var A = (function () {
     function A() {
     }
@@ -22,7 +23,7 @@ var A = (function () {
         return aVal;
     };
     return A;
-})();
+}());
 module.exports = A;
 
 
