@@ -9,13 +9,15 @@ import defaultBinding, * as nameSpaceBinding  from "./server";
 export var x = new nameSpaceBinding.a();
 
 //// [server.js]
+"use strict";
 var a = (function () {
     function a() {
     }
     return a;
-})();
+}());
 exports.a = a;
 //// [client.js]
+"use strict";
 var server_1 = require("./server"), nameSpaceBinding = server_1;
 exports.x = new nameSpaceBinding.a();
 
