@@ -11,9 +11,11 @@ import * as nameSpaceBinding2 from "./es6ImportNameSpaceImport_0"; // elide this
 
 
 //// [es6ImportNameSpaceImport_0.js]
+"use strict";
 exports.a = 10;
 //// [es6ImportNameSpaceImport_1.js]
-var nameSpaceBinding = require("./es6ImportNameSpaceImport_0");
+"use strict";
+const nameSpaceBinding = require("./es6ImportNameSpaceImport_0");
 var x = nameSpaceBinding.a;
 
 
