@@ -9,9 +9,11 @@ import { a } from "./es6ImportNamedImportInExportAssignment_0";
 export = a;
 
 //// [es6ImportNamedImportInExportAssignment_0.js]
+"use strict";
 exports.a = 10;
 //// [es6ImportNamedImportInExportAssignment_1.js]
-var es6ImportNamedImportInExportAssignment_0_1 = require("./es6ImportNamedImportInExportAssignment_0");
+"use strict";
+const es6ImportNamedImportInExportAssignment_0_1 = require("./es6ImportNamedImportInExportAssignment_0");
 module.exports = es6ImportNamedImportInExportAssignment_0_1.a;
 
 
