@@ -1,4 +1,4 @@
-//// [exportAssignmentAndDeclaration.ts]
+//// [foo_0.ts]
 export enum E1 {
 	A,B,C
 }
@@ -10,8 +10,9 @@ class C1 {
 // Invalid, as there is already an exported member.
 export = C1;
 
-//// [exportAssignmentAndDeclaration.js]
+//// [foo_0.js]
 define(["require", "exports"], function (require, exports) {
+    "use strict";
     (function (E1) {
         E1[E1["A"] = 0] = "A";
         E1[E1["B"] = 1] = "B";
@@ -22,6 +23,6 @@ define(["require", "exports"], function (require, exports) {
         function C1() {
         }
         return C1;
-    })();
+    }());
     return C1;
 });
