@@ -15,13 +15,15 @@ var y = new foo({a: "test", b: 42}); // Should be OK
 var z: number = y.test.b;
 
 //// [foo_0.js]
+"use strict";
 var Foo = (function () {
     function Foo(x) {
     }
     return Foo;
-})();
+}());
 module.exports = Foo;
 //// [foo_1.js]
+"use strict";
 var foo = require("./foo_0");
 var x = new foo(true); // Should error
 var y = new foo({ a: "test", b: 42 }); // Should be OK
