@@ -13,13 +13,15 @@ var y:number = x.test;
 
 
 //// [foo_0.js]
+"use strict";
 var Foo = (function () {
     function Foo() {
     }
     return Foo;
-})();
+}());
 module.exports = Foo;
 //// [foo_1.js]
+"use strict";
 var foo = require("./foo_0");
 var x = new foo();
 var y = x.test;
