@@ -15,11 +15,12 @@ var r: string = m.foo;
 
 //// [exportAssignmentOfGenericType1_0.js]
 define(["require", "exports"], function (require, exports) {
+    "use strict";
     var T = (function () {
         function T() {
         }
         return T;
-    })();
+    }());
     return T;
 });
 //// [exportAssignmentOfGenericType1_1.js]
@@ -29,13 +30,14 @@ var __extends = (this && this.__extends) || function (d, b) {
     d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 define(["require", "exports", "exportAssignmentOfGenericType1_0"], function (require, exports, q) {
+    "use strict";
     var M = (function (_super) {
         __extends(M, _super);
         function M() {
             _super.apply(this, arguments);
         }
         return M;
-    })(q);
+    }(q));
     var m;
     var r = m.foo;
 });
