@@ -35,6 +35,7 @@ export let h1: D = new D;
 
 
 //// [exportNonInitializedVariablesCommonJS.js]
+"use strict";
 var ;
 let;
 var ;
@@ -42,7 +43,7 @@ var A = (function () {
     function A() {
     }
     return A;
-})();
+}());
 var B;
 (function (B) {
     B.a = 1, B.c = 2;
@@ -60,7 +61,7 @@ var D = (function () {
     function D() {
     }
     return D;
-})();
+}());
 exports.e1 = new D;
 exports.f1 = new D;
 exports.g1 = new D;
