@@ -10,11 +10,12 @@ export function test(foo: Foo) {
 
 
 //// [exportVisibility.js]
+"use strict";
 var Foo = (function () {
     function Foo() {
     }
     return Foo;
-})();
+}());
 exports.Foo = Foo;
 exports.foo = new Foo();
 function test(foo) {
