@@ -35,6 +35,7 @@ export { v, f, C, I, E, D, M, N, T, a };
 
 
 //// [t1.js]
+"use strict";
 var v = 1;
 exports.v = v;
 function f() { }
@@ -56,6 +57,7 @@ exports.M = M;
 var a = M.x;
 exports.a = a;
 //// [t2.js]
+"use strict";
 var t1_1 = require("./t1");
 exports.v = t1_1.v;
 exports.f = t1_1.f;
@@ -64,7 +66,8 @@ exports.E = t1_1.E;
 exports.M = t1_1.M;
 exports.a = t1_1.a;
 //// [t3.js]
-var t1_1 = require("./t1");
+"use strict";
+const t1_1 = require("./t1");
 exports.v = t1_1.v;
 exports.f = t1_1.f;
 exports.C = t1_1.C;
