@@ -16,7 +16,7 @@ var C = (function () {
     function C() {
     }
     return C;
-})();
+}());
 var D = (function (_super) {
     __extends(D, _super);
     function D() {
@@ -24,4 +24,4 @@ var D = (function (_super) {
     }
     D.prototype.baz = function () { };
     return D;
-})(C);
+}(C));
