@@ -122,7 +122,7 @@ var A = (function () {
         return null;
     };
     return A;
-})();
+}());
 var B = (function (_super) {
     __extends(B, _super);
     function B() {
@@ -137,7 +137,7 @@ var B = (function (_super) {
         return null;
     };
     return B;
-})(A);
+}(A));
 var i;
 for (var x in i[42]) { }
 var M;
@@ -146,7 +146,7 @@ var M;
         function X() {
         }
         return X;
-    })();
+    }());
     M.X = X;
 })(M || (M = {}));
 for (var x in M) { }
