@@ -1,4 +1,5 @@
 //// [forContinueStatements.ts]
+
 for (; ;) {
     continue;
 }
@@ -61,7 +62,6 @@ SEVEN: for (;;)
         for (;;)
             continue SEVEN;
 EIGHT: for (;;) {
-    var fn = function () {
-    };
+    var fn = function () { };
     continue EIGHT;
 }
