@@ -1,4 +1,5 @@
 //// [functionReturn.ts]
+
 function f0(): void { }
 function f1() {
     var n: any = f0();
@@ -15,16 +16,12 @@ function f5(): string {
 }
 
 //// [functionReturn.js]
-function f0() {
-}
+function f0() { }
 function f1() {
     var n = f0();
 }
-function f2() {
-}
-function f3() {
-    return;
-}
+function f2() { }
+function f3() { return; }
 function f4() {
     return '';
     return;
