@@ -118,21 +118,21 @@ var Base = (function () {
     function Base() {
     }
     return Base;
-})();
+}());
 var Derived = (function (_super) {
     __extends(Derived, _super);
     function Derived() {
         _super.apply(this, arguments);
     }
     return Derived;
-})(Base);
+}(Base));
 var Derived2 = (function (_super) {
     __extends(Derived2, _super);
     function Derived2() {
         _super.apply(this, arguments);
     }
     return Derived2;
-})(Derived);
+}(Derived));
 var b;
 var d1;
 var d2;
@@ -187,7 +187,7 @@ var C = (function () {
         return x;
     };
     return C;
-})();
+}());
 var c = new C(b, d1);
 var r4 = c.foo(d1, d2); // Base
 var r5 = c.foo2(b, d2); // Derived
