@@ -93,7 +93,7 @@ var Portal;
                 Validator.prototype.destroy = function () { };
                 Validator.prototype._validate = function (value) { return 0; };
                 return Validator;
-            })();
+            }());
             Validators.Validator = Validator;
         })(Validators = Controls.Validators || (Controls.Validators = {}));
     })(Controls = Portal.Controls || (Portal.Controls = {}));
@@ -112,7 +112,7 @@ var PortalFx;
                         _super.call(this, message);
                     }
                     return Validator;
-                })(Portal.Controls.Validators.Validator);
+                }(Portal.Controls.Validators.Validator));
                 Validators.Validator = Validator;
             })(Validators = Controls.Validators || (Controls.Validators = {}));
         })(Controls = ViewModels.Controls || (ViewModels.Controls = {}));
@@ -123,4 +123,4 @@ var ViewModel = (function () {
         this.validators = ko.observableArray();
     }
     return ViewModel;
-})();
+}());
