@@ -22,6 +22,7 @@ export class B<T2> {
 
 //// [genericClassesInModule2.js]
 define(["require", "exports"], function (require, exports) {
+    "use strict";
     var A = (function () {
         function A(callback) {
             this.callback = callback;
@@ -31,13 +32,13 @@ define(["require", "exports"], function (require, exports) {
             var child = new B(this);
         };
         return A;
-    })();
+    }());
     exports.A = A;
     var B = (function () {
         function B(parent) {
             this.parent = parent;
         }
         return B;
-    })();
+    }());
     exports.B = B;
 });
