@@ -25,23 +25,23 @@ var BaseEvent = (function () {
     function BaseEvent() {
     }
     return BaseEvent;
-})();
+}());
 var MyEvent = (function (_super) {
     __extends(MyEvent, _super);
     function MyEvent() {
         _super.apply(this, arguments);
     }
     return MyEvent;
-})(BaseEvent);
+}(BaseEvent));
 var BaseEventWrapper = (function () {
     function BaseEventWrapper() {
     }
     return BaseEventWrapper;
-})();
+}());
 var MyEventWrapper = (function (_super) {
     __extends(MyEventWrapper, _super);
     function MyEventWrapper() {
         _super.apply(this, arguments);
     }
     return MyEventWrapper;
-})(BaseEventWrapper);
+}(BaseEventWrapper));
