@@ -30,7 +30,7 @@ var Base = (function () {
     function Base() {
     }
     return Base;
-})();
+}());
 var Derived = (function (_super) {
     __extends(Derived, _super);
     function Derived() {
@@ -48,4 +48,4 @@ var Derived = (function (_super) {
         };
     }
     return Derived;
-})(Base);
+}(Base));
