@@ -95,28 +95,28 @@ var Foo = (function () {
     function Foo() {
     }
     return Foo;
-})();
+}());
 var Bar = (function (_super) {
     __extends(Bar, _super);
     function Bar() {
         _super.apply(this, arguments);
     }
     return Bar;
-})(Foo);
+}(Foo));
 var Bar2 = (function (_super) {
     __extends(Bar2, _super);
     function Bar2() {
         _super.apply(this, arguments);
     }
     return Bar2;
-})(Foo);
+}(Foo));
 var Bar3 = (function (_super) {
     __extends(Bar3, _super);
     function Bar3() {
         _super.apply(this, arguments);
     }
     return Bar3;
-})(Foo);
+}(Foo));
 // another level of indirection
 var M;
 (function (M) {
@@ -124,35 +124,35 @@ var M;
         function Foo() {
         }
         return Foo;
-    })();
+    }());
     var Baz = (function (_super) {
         __extends(Baz, _super);
         function Baz() {
             _super.apply(this, arguments);
         }
         return Baz;
-    })(Foo);
+    }(Foo));
     var Bar = (function (_super) {
         __extends(Bar, _super);
         function Bar() {
             _super.apply(this, arguments);
         }
         return Bar;
-    })(Foo);
+    }(Foo));
     var Bar2 = (function (_super) {
         __extends(Bar2, _super);
         function Bar2() {
             _super.apply(this, arguments);
         }
         return Bar2;
-    })(Foo);
+    }(Foo));
     var Bar3 = (function (_super) {
         __extends(Bar3, _super);
         function Bar3() {
             _super.apply(this, arguments);
         }
         return Bar3;
-    })(Foo);
+    }(Foo));
 })(M || (M = {}));
 // two levels of privates
 var M2;
@@ -161,21 +161,21 @@ var M2;
         function Foo() {
         }
         return Foo;
-    })();
+    }());
     var Baz = (function (_super) {
         __extends(Baz, _super);
         function Baz() {
             _super.apply(this, arguments);
         }
         return Baz;
-    })(Foo);
+    }(Foo));
     var Bar = (function (_super) {
         __extends(Bar, _super);
         function Bar() {
             _super.apply(this, arguments);
         }
         return Bar;
-    })(Foo);
+    }(Foo));
     var b;
     var r1 = b.z;
     var r2 = b.x; // error
@@ -186,12 +186,12 @@ var M2;
             _super.apply(this, arguments);
         }
         return Bar2;
-    })(Foo);
+    }(Foo));
     var Bar3 = (function (_super) {
         __extends(Bar3, _super);
         function Bar3() {
             _super.apply(this, arguments);
         }
         return Bar3;
-    })(Foo);
+    }(Foo));
 })(M2 || (M2 = {}));
