@@ -51,52 +51,52 @@ var Foo = (function () {
     function Foo() {
     }
     return Foo;
-})();
+}());
 var Bar = (function () {
     function Bar() {
     }
     return Bar;
-})();
+}());
 var Bar2 = (function () {
     function Bar2() {
     }
     return Bar2;
-})();
+}());
 var Bar3 = (function () {
     function Bar3() {
     }
     return Bar3;
-})();
+}());
 var Bar4 = (function () {
     function Bar4() {
     }
     return Bar4;
-})();
+}());
 var Bar5 = (function (_super) {
     __extends(Bar5, _super);
     function Bar5() {
         _super.apply(this, arguments);
     }
     return Bar5;
-})(Foo);
+}(Foo));
 var Bar6 = (function (_super) {
     __extends(Bar6, _super);
     function Bar6() {
         _super.apply(this, arguments);
     }
     return Bar6;
-})(Foo);
+}(Foo));
 var Bar7 = (function (_super) {
     __extends(Bar7, _super);
     function Bar7() {
         _super.apply(this, arguments);
     }
     return Bar7;
-})(Foo);
+}(Foo));
 var Bar8 = (function (_super) {
     __extends(Bar8, _super);
     function Bar8() {
         _super.apply(this, arguments);
     }
     return Bar8;
-})(Foo);
+}(Foo));
