@@ -11,14 +11,16 @@ class Hello extends Greeter { }
 
 
 //// [importAsBaseClass_0.js]
+"use strict";
 var Greeter = (function () {
     function Greeter() {
     }
     Greeter.prototype.greet = function () { return 'greet'; };
     return Greeter;
-})();
+}());
 exports.Greeter = Greeter;
 //// [importAsBaseClass_1.js]
+"use strict";
 var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
@@ -31,4 +33,4 @@ var Hello = (function (_super) {
         _super.apply(this, arguments);
     }
     return Hello;
-})(Greeter);
+}(Greeter));
