@@ -12,13 +12,15 @@ export var x: typeof a;
 
 
 //// [importDeclarationUsedAsTypeQuery_require.js]
+"use strict";
 var B = (function () {
     function B() {
     }
     return B;
-})();
+}());
 exports.B = B;
 //// [importDeclarationUsedAsTypeQuery_1.js]
+"use strict";
 
 
 //// [importDeclarationUsedAsTypeQuery_require.d.ts]
