@@ -12,11 +12,12 @@ export = Bar;
 
 //// [Foo.js]
 define(["require", "exports"], function (require, exports) {
+    "use strict";
     var Foo = (function () {
         function Foo() {
         }
         return Foo;
-    })();
+    }());
     return Foo;
 });
 //// [Bar.js]
@@ -26,12 +27,13 @@ var __extends = (this && this.__extends) || function (d, b) {
     d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
 };
 define(["require", "exports", 'Foo'], function (require, exports, Error) {
+    "use strict";
     var Bar = (function (_super) {
         __extends(Bar, _super);
         function Bar() {
             _super.apply(this, arguments);
         }
         return Bar;
-    })(Error);
+    }(Error));
     return Bar;
 });
