@@ -12,13 +12,15 @@ var r: string = s.foo;
 
 
 //// [importUsedInExtendsList1_require.js]
+"use strict";
 var Super = (function () {
     function Super() {
     }
     return Super;
-})();
+}());
 exports.Super = Super;
 //// [importUsedInExtendsList1_1.js]
+"use strict";
 var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
@@ -32,6 +34,6 @@ var Sub = (function (_super) {
         _super.apply(this, arguments);
     }
     return Sub;
-})(foo.Super);
+}(foo.Super));
 var s;
 var r = s.foo;
