@@ -23,6 +23,7 @@ var x = new UserServices().getUserName();
 
 //// [file1.js]
 define(["require", "exports"], function (require, exports) {
+    "use strict";
     var App;
     (function (App) {
         var Services;
@@ -34,7 +35,7 @@ define(["require", "exports"], function (require, exports) {
                     return "Bill Gates";
                 };
                 return UserServices;
-            })();
+            }());
             Services.UserServices = UserServices;
         })(Services = App.Services || (App.Services = {}));
     })(App || (App = {}));
@@ -43,6 +44,7 @@ define(["require", "exports"], function (require, exports) {
 });
 //// [file2.js]
 define(["require", "exports", "file1"], function (require, exports, appJs) {
+    "use strict";
     var Services = appJs.Services;
     var UserServices = Services.UserServices;
     var x = new UserServices().getUserName();
