@@ -12,15 +12,17 @@ var v = new hostVar.Host();
 
 //// [host.js]
 define(["require", "exports"], function (require, exports) {
+    "use strict";
     var Host = (function () {
         function Host() {
         }
         return Host;
-    })();
+    }());
     exports.Host = Host;
 });
 //// [consumer.js]
 define(["require", "exports", "host"], function (require, exports, host) {
+    "use strict";
     var hostVar = host;
     var v = new hostVar.Host();
 });
