@@ -8,9 +8,10 @@ class foo { }
 
 //// [importedModuleClassNameClash.js]
 define(["require", "exports"], function (require, exports) {
+    "use strict";
     var foo = (function () {
         function foo() {
         }
         return foo;
-    })();
+    }());
 });
