@@ -14,11 +14,11 @@ var a = (function (_super) {
         _super.apply(this, arguments);
     }
     return a;
-})(b);
+}(b));
 var b = (function (_super) {
     __extends(b, _super);
     function b() {
         _super.apply(this, arguments);
     }
     return b;
-})(a);
+}(a));
