@@ -71,7 +71,7 @@ var Control = (function () {
     function Control() {
     }
     return Control;
-})();
+}());
 var Button = (function (_super) {
     __extends(Button, _super);
     function Button() {
@@ -79,7 +79,7 @@ var Button = (function (_super) {
     }
     Button.prototype.select = function () { };
     return Button;
-})(Control);
+}(Control));
 var TextBox = (function (_super) {
     __extends(TextBox, _super);
     function TextBox() {
@@ -87,33 +87,33 @@ var TextBox = (function (_super) {
     }
     TextBox.prototype.select = function () { };
     return TextBox;
-})(Control);
+}(Control));
 var ImageBase = (function (_super) {
     __extends(ImageBase, _super);
     function ImageBase() {
         _super.apply(this, arguments);
     }
     return ImageBase;
-})(Control);
+}(Control));
 var Image1 = (function (_super) {
     __extends(Image1, _super);
     function Image1() {
         _super.apply(this, arguments);
     }
     return Image1;
-})(Control);
+}(Control));
 var Locations = (function () {
     function Locations() {
     }
     Locations.prototype.select = function () { };
     return Locations;
-})();
+}());
 var Locations1 = (function () {
     function Locations1() {
     }
     Locations1.prototype.select = function () { };
     return Locations1;
-})();
+}());
 var sc;
 var c;
 var b;
