@@ -24,7 +24,7 @@ var a = (function () {
         return "10";
     };
     return a;
-})();
+}());
 var b = (function (_super) {
     __extends(b, _super);
     function b() {
@@ -34,4 +34,4 @@ var b = (function (_super) {
         return "20";
     };
     return b;
-})(a);
+}(a));
