@@ -33,11 +33,11 @@ var a = (function () {
         configurable: true
     });
     return a;
-})();
+}());
 var b = (function (_super) {
     __extends(b, _super);
     function b() {
         _super.apply(this, arguments);
     }
     return b;
-})(a);
+}(a));
