@@ -22,11 +22,11 @@ var a = (function () {
         return "20";
     };
     return a;
-})();
+}());
 var b = (function (_super) {
     __extends(b, _super);
     function b() {
         _super.apply(this, arguments);
     }
     return b;
-})(a);
+}(a));
