@@ -17,14 +17,14 @@ var A = (function () {
     function A() {
     }
     return A;
-})();
+}());
 var B = (function (_super) {
     __extends(B, _super);
     function B() {
         _super.apply(this, arguments);
     }
     return B;
-})(A);
+}(A));
 var a = new A();
 var b1 = new B(); // no error
 var b2 = new B(); // no error
