@@ -36,7 +36,7 @@ var a = (function () {
         configurable: true
     });
     return a;
-})();
+}());
 var b = (function (_super) {
     __extends(b, _super);
     function b() {
@@ -52,4 +52,4 @@ var b = (function (_super) {
         configurable: true
     });
     return b;
-})(a);
+}(a));
