@@ -28,7 +28,7 @@ var a = (function () {
         configurable: true
     });
     return a;
-})();
+}());
 var b = (function (_super) {
     __extends(b, _super);
     function b() {
@@ -38,4 +38,4 @@ var b = (function (_super) {
         return "20";
     };
     return b;
-})(a);
+}(a));
