@@ -28,14 +28,14 @@ var Base = (function () {
         }
     }
     return Base;
-})();
+}());
 var Derived = (function (_super) {
     __extends(Derived, _super);
     function Derived() {
         _super.apply(this, arguments);
     }
     return Derived;
-})(Base);
+}(Base));
 // Ok
 new Derived("", "");
 new Derived("");
