@@ -34,14 +34,14 @@ var C = (function () {
         return "123";
     };
     return C;
-})();
+}());
 var D = (function (_super) {
     __extends(D, _super);
     function D() {
         _super.apply(this, arguments);
     }
     return D;
-})(C);
+}(C));
 var D;
 (function (D) {
     function foo() {
@@ -59,4 +59,4 @@ var E = (function (_super) {
         return this.foo();
     };
     return E;
-})(D);
+}(D));
