@@ -35,7 +35,7 @@ var C = (function () {
     }
     C.prototype.foo = function (x) { return x; };
     return C;
-})();
+}());
 var D = (function (_super) {
     __extends(D, _super);
     function D() {
@@ -47,7 +47,7 @@ var D = (function (_super) {
     D.prototype.other = function (x) { return x; };
     D.prototype.bar = function () { };
     return D;
-})(C);
+}(C));
 var D2 = (function (_super) {
     __extends(D2, _super);
     function D2() {
@@ -58,4 +58,4 @@ var D2 = (function (_super) {
     D2.prototype.other = function (x) { return x; };
     D2.prototype.bar = function () { };
     return D2;
-})(C);
+}(C));
