@@ -50,47 +50,47 @@ var C1 = (function () {
     function C1() {
     }
     return C1;
-})();
+}());
 var C2 = (function () {
     function C2() {
     }
     return C2;
-})();
+}());
 var C3 = (function () {
     function C3() {
     }
     return C3;
-})();
+}());
 var C4 = (function (_super) {
     __extends(C4, _super);
     function C4() {
         _super.apply(this, arguments);
     }
     return C4;
-})(C1);
+}(C1));
 var C5 = (function (_super) {
     __extends(C5, _super);
     function C5() {
         _super.apply(this, arguments);
     }
     return C5;
-})(C2);
+}(C2));
 var C6 = (function (_super) {
     __extends(C6, _super);
     function C6() {
         _super.apply(this, arguments);
     }
     return C6;
-})(C3);
+}(C3));
 var C7 = (function () {
     function C7() {
     }
     return C7;
-})();
+}());
 var C8 = (function (_super) {
     __extends(C8, _super);
     function C8() {
         _super.apply(this, arguments);
     }
     return C8;
-})(C7);
+}(C7));
