@@ -14,6 +14,7 @@ export module c {
 export var d = new c.b.c();
 
 //// [internalAliasInitializedModuleInsideLocalModuleWithoutExportAccessError.js]
+"use strict";
 var a;
 (function (a) {
     var b;
@@ -22,7 +23,7 @@ var a;
             function c() {
             }
             return c;
-        })();
+        }());
         b.c = c;
     })(b = a.b || (a.b = {}));
 })(a = exports.a || (exports.a = {}));
