@@ -63,19 +63,19 @@ var C = (function () {
     function C() {
     }
     return C;
-})();
+}());
 var C2 = (function (_super) {
     __extends(C2, _super);
     function C2() {
         _super.apply(this, arguments);
     }
     return C2;
-})(C);
+}(C));
 var D = (function () {
     function D() {
     }
     return D;
-})();
+}());
 function F(x) { return 42; }
 var M;
 (function (M) {
@@ -83,7 +83,7 @@ var M;
         function A() {
         }
         return A;
-    })();
+    }());
     M.A = A;
     function F2(x) { return x.toString(); }
     M.F2 = F2;
