@@ -37,13 +37,13 @@ var C = (function () {
     }
     C.prototype.dispose = function () { };
     return C;
-})();
+}());
 var D = (function (_super) {
     __extends(D, _super);
     function D() {
         _super.apply(this, arguments);
     }
     return D;
-})(C);
+}(C));
 function fn10() { return { id: 12 }; }
 function fn11() { return new C(); }
