@@ -5,7 +5,9 @@ run(1);
 
 
 //// [isolatedModulesPlainFile-System.js]
-System.register([], function(exports_1) {
+System.register([], function(exports_1, context_1) {
+    "use strict";
+    var __moduleName = context_1 && context_1.id;
     return {
         setters:[],
         execute: function() {
