@@ -24,6 +24,7 @@ class TestComponent extends React.Component<any, {}> {
 
 
 //// [consumer.jsx]
+"use strict";
 var __extends = (this && this.__extends) || function (d, b) {
     for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
     function __() { this.constructor = d; }
@@ -40,4 +41,4 @@ var TestComponent = (function (_super) {
         return <BaseComponent />;
     };
     return TestComponent;
-})(React.Component);
+}(React.Component));
