@@ -12,4 +12,7 @@ Foo(() =>
 //// [lambdaASIEmit.js]
 function Foo(x) {
 }
-Foo(function () { return 127; });
+Foo(function () {
+    // do something
+    return 127;
+});
