@@ -48,29 +48,29 @@ var C = (function () {
     function C() {
     }
     return C;
-})();
+}());
 var C2 = (function () {
     function C2() {
     }
     return C2;
-})();
+}());
 var D = (function (_super) {
     __extends(D, _super);
     function D() {
         _super.apply(this, arguments);
     }
     return D;
-})(C);
+}(C));
 var M;
 (function (M) {
     var C = (function () {
         function C() {
         }
         return C;
-    })();
+    }());
     var C2 = (function () {
         function C2() {
         }
         return C2;
-    })();
+    }());
 })(M || (M = {}));
